@@ -19,6 +19,8 @@ from ._wrangler import (  # noqa: F401
     delete_partitions_and_data,
     delete_table_and_data,
     delete_database_and_data,
+    save_query_to_parquet,
+    dataframe_to_temp_table,
 )
 
 from ._sql_render import (  # noqa: F401
@@ -26,4 +28,4 @@ from ._sql_render import (  # noqa: F401
     render_sql_template,
 )
 
-__version__ = "5.0.0"
+__version__ = "5.2.0"
